Documentation
¶
Index ¶
- func AfterOpt[T any](f form.OptTimeField[T], t time.Time) form.Rule[T]
- func AfterOptWithCode[T any](f form.OptTimeField[T], t time.Time, code form.Code) form.Rule[T]
- func BeforeOpt[T any](f form.OptTimeField[T], t time.Time) form.Rule[T]
- func BeforeOptWithCode[T any](f form.OptTimeField[T], t time.Time, code form.Code) form.Rule[T]
- func BetweenFloat64Opt[T any](f form.OptFloat64Field[T], min, max float64) form.Rule[T]
- func BetweenFloat64OptWithCode[T any](f form.OptFloat64Field[T], min, max float64, code form.Code) form.Rule[T]
- func BetweenIntOpt[T any](f form.OptIntField[T], min, max int) form.Rule[T]
- func BetweenIntOptWithCode[T any](f form.OptIntField[T], min, max int, code form.Code) form.Rule[T]
- func BetweenTimeOpt[T any](f form.OptTimeField[T], min, max time.Time) form.Rule[T]
- func BetweenTimeOptWithCode[T any](f form.OptTimeField[T], min, max time.Time, code form.Code) form.Rule[T]
- func MaxFloat64Opt[T any](f form.OptFloat64Field[T], n float64) form.Rule[T]
- func MaxFloat64OptWithCode[T any](f form.OptFloat64Field[T], n float64, code form.Code) form.Rule[T]
- func MaxOpt[T any](f form.OptIntField[T], n int) form.Rule[T]
- func MaxOptWithCode[T any](f form.OptIntField[T], n int, code form.Code) form.Rule[T]
- func MinFloat64Opt[T any](f form.OptFloat64Field[T], n float64) form.Rule[T]
- func MinFloat64OptWithCode[T any](f form.OptFloat64Field[T], n float64, code form.Code) form.Rule[T]
- func MinOpt[T any](f form.OptIntField[T], n int) form.Rule[T]
- func MinOptWithCode[T any](f form.OptIntField[T], n int, code form.Code) form.Rule[T]
- func OptionalFloat64[T any](f form.OptFloat64Field[T], rules ...form.Rule[T]) form.Rule[T]
- func OptionalInt[T any](f form.OptIntField[T], rules ...form.Rule[T]) form.Rule[T]
- func OptionalPtr[T any, V any](f form.Field[T, *V], rules ...form.Rule[T]) form.Rule[T]
- func OptionalSlice[T any, V any](f form.Field[T, []V], rules ...form.Rule[T]) form.Rule[T]
- func OptionalString[T any](f form.StringField[T], rules ...form.Rule[T]) form.Rule[T]
- func OptionalTime[T any](f form.OptTimeField[T], rules ...form.Rule[T]) form.Rule[T]
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AfterOptWithCode ¶
func BeforeOptWithCode ¶
func BetweenFloat64Opt ¶
func BetweenIntOpt ¶
func BetweenIntOptWithCode ¶
func BetweenTimeOpt ¶
func BetweenTimeOptWithCode ¶
func MaxFloat64Opt ¶
func MaxFloat64OptWithCode ¶
func MaxOptWithCode ¶
func MinFloat64Opt ¶
func MinFloat64OptWithCode ¶
func MinOptWithCode ¶
func OptionalFloat64 ¶
OptionalFloat64 applies nested rules only when the float64 pointer field is non-nil.
func OptionalInt ¶
OptionalInt applies nested rules only when the int pointer field is non-nil.
func OptionalPtr ¶
func OptionalSlice ¶
func OptionalString ¶
func OptionalTime ¶
OptionalTime applies nested rules only when the time pointer field is non-nil.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.